# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['django_swagger_tester',
 'django_swagger_tester.response_validation',
 'django_swagger_tester.response_validation.base']

package_data = \
{'': ['*']}

install_requires = \
['django>=2.2,<4.0', 'djangorestframework']

setup_kwargs = {
    'name': 'django-swagger-tester',
    'version': '0.2.3',
    'description': 'Test utility for your Swagger documentation.',
    'long_description': '#####################\nDjango Swagger Tester\n#####################\n\n.. image:: https://img.shields.io/pypi/v/django-swagger-tester.svg\n    :target: https://pypi.org/project/django-swagger-tester/\n\n.. image:: https://img.shields.io/pypi/pyversions/django-swagger-tester.svg\n    :target: https://pypi.org/project/django-swagger-tester/\n\n.. image:: https://img.shields.io/pypi/djversions/django-swagger-tester.svg\n    :target: https://pypi.python.org/pypi/django-swagger-tester\n\n.. image:: https://readthedocs.org/projects/django-swagger-tester/badge/?version=latest\n    :target: https://django-swagger-tester.readthedocs.io/en/latest/?badge=latest\n    :alt: Documentation Status\n\n.. image:: https://codecov.io/gh/sondrelg/django-swagger-tester/branch/master/graph/badge.svg\n    :target: https://codecov.io/gh/sondrelg/django-swagger-tester\n\n.. image:: https://img.shields.io/badge/code%20style-black-000000.svg\n    :target: https://pypi.org/project/django-swagger-tester/\n\n.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white\n    :target: https://github.com/pre-commit/pre-commit\n\nThis package lets you test the integrity of your OpenAPI/Swagger documentation.\n\nThe package has three main features:\n\n* `Testing response documentation <testing_with_django_swagger_tester.html>`_\n* `Testing input documentation <testing_with_django_swagger_tester.html>`_\n* `Ensuring all documentation complies with a case standard <configuration.html>`_. Available standards include:\n\n    * camelCase\n    * snake_case\n    * kebab-case\n    * PascalCase\n\n\nDjango Swagger Tester is currently compatible with Swagger documentation generated using drf_yasg_, or docs rendered from a schema file (yaml/json). If you\'re using another method to generate your documentation and would like to use this library, feel free to add an issue, or create a PR - expanding the package is relatively simple.\n\n************\nInstallation\n************\n\nInstall using pip:\n\n.. code:: bash\n\n    pip install django-swagger-tester\n\n*************\nConfiguration\n*************\n\nSettings\n========\n\nTo add Django Swagger Settings in your project, add a ``SWAGGER_TESTER`` object to your ``settings.py``:\n\n.. code-block:: python\n\n    SWAGGER_TESTER = {\n        \'CASE\': \'camel case\',\n        \'PATH\': BASE_DIR + \'/openapi-schema.yml\'  # not required for drf_yasg\n    }\n\n\nSetting parameters\n==================\n\n* CASE\n    The case standard you wish to enforce for your documentation.\n\n    Needs to be one of the following:\n\n        * :code:`camel case`\n        * :code:`snake case`\n        * :code:`pascal case`\n        * :code:`kebab case`\n        * :code:`None`\n\n    All documentation is tested to make sure values are correctly cased, unless you specify :code:`None` to skip this feature.\n\n    Example:\n\n    .. code-block:: python\n\n        SWAGGER_TESTER = {\n            \'CASE\': \'snake case\',\n        }\n\n    Default: :code:`camel case`\n\n* PATH\n    The path to your OpenAPI specification.\n\n    Example:\n\n    .. code-block:: python\n\n        SWAGGER_TESTER = {\n            \'PATH\': BASE_DIR + \'/openapi-schema.yml\',\n        }\n\n\n    *This setting is not required if your swagger docs are generated.*\n\n**********************************\nTesting with django Swagger Tester\n**********************************\n\nThis document contains an in-depth explanation on how the package works, and how to best implement it.\n\nResponse validation\n===================\n\nAn OpenAPI schema should generally span all APIs you provide. For each API, there may be several methods to document (GET, PUT, POST, DELETE, ...), and for each method you may have several responses (200, 400, 401, 404, 5XX). Seeing that at least parts of the OpenAPI schema used for rendering your swagger docs will need to be maintained manually, it is easy to see how bugs might be introduced in the documentation over time. By testing your response documentation against your actual API responses, you can make sure that errors don\'t pass silently.\n\nThis functionality is currently compatible with rendered static schema, or generated `drf_yasg`_ swagger docs.\n\n.. _Drf_yasg: https://github.com/axnsan12/drf-yasg\n\nAt the core, the logic for testing an OpenAPI schema is the same, regardless of your Swagger implementation. However, because packages like drf_yasg_ lets you generate documentation on the fly, we need custom logic for extracting the schema. The result is that we need separate implementations for separate documentation implementations, simply for loading schemas.\n\nThe validate_response function\n------------------------------\n\nThe ``validate_response`` function takes three required inputs:\n\n* response\n    description: This should be the response object returned from an API call. Note: Make sure to pass the response object, not the response data, as we need to match both ``status_code`` and ``json`` to the OpenAPI schema.\n    type: Response\n\n* method\n    description: This should be the HTTP method used to get the reponse.\n    type: string\n    example: \'GET\'\n\n* endpoint_url\n    description: This should be the resolvable path of your endpoint.\n    type: string\n    example: \'api/v1/test\'\n\nIn addition, the function also takes one optional input:\n\n* ignore_case\n    description: List of keys for which we will skip case-validation. This can be useful for when you\'ve made a conscious decision to, e.g., keep an acronym upper-cased although you have camelCase as a general standard.\n    type: list of strings\n    example: [\'API\',]\n\nDynamically rendered OpenAPI schema with drf_yasg\n-------------------------------------------------\n\nThe drf_yasg_ implementation can be imported from its own project folder:\n\n.. code-block:: python\n\n    from django_swagger_tester.response_validation.drf_yasg import validate_response\n\n\nStatically rendered OpenAPI schema\n----------------------------------\n\nWhen testing a static schema (located locally in your project), make sure to point to the right file in the ``PATH`` setting.\n\nThe static schema implementation can be imported from its own project folder:\n\n.. code-block:: python\n\n    from django_swagger_tester.response_validation.static_schema import validate_response\n\n\nExamples\n--------\n\nA pytest implementation might look like this:\n\n.. code:: python\n\n    def test_response_documentation(client):\n        response = client.get(\'api/v1/test/\')\n\n        assert response.status_code == 200\n        assert response.json() == expected_response\n\n        # Test Swagger documentation\n        validate_response(response=response, method=\'GET\', endpoint_url=\'api/v1/test/\', ignore_case=[])\n\nA Django-test implementation might look like this:\n\n.. code-block:: python\n\n    class MyApiTest(APITestCase):\n\n        def setUp(self) -> None:\n            user, _ = User.objects.update_or_create(username=\'test_user\')\n            self.client.force_authenticate(user=user)\n            self.path = \'/api/v1/test/\'\n\n        def test_get_200(self) -> None:\n            """\n            Verifies that a 200 is returned for a valid GET request to the /test/ endpoint.\n            """\n            response = self.client.get(self.path, headers={\'Content-Type\': \'application/json\'})\n            expected_response = [...]\n\n            self.assertEqual(response.status_code, 200)\n            self.assertEqual(response.json(), expected_response)\n\n            # Test Swagger documentation\n            validate_response(response=response, method=\'GET\', endpoint_url=self.path)\n\nYou can also test more than a single response at the time.\n\n.. code:: python\n\n    def test_response_documentation(client):\n        # 201 - Resource created\n        response = client.post(\'api/v1/test/\', data=...)\n        validate_response(response=response, method=\'POST\', endpoint_url=\'api/v1/test/\', ignore_case=[])\n\n        # 200 - Idempotency --> if an object exists, return it with a 200 without creating a new resource\n        response = client.post(\'api/v1/test/\', data=...)\n        validate_response(response=response, method=\'POST\', endpoint_url=\'api/v1/test/\', ignore_case=[])\n\n        # 400 - Bad data\n        response = client.post(\'api/v1/test/\', data=bad_data)\n        validate_response(response=response, method=\'POST\', endpoint_url=\'api/v1/test/\', ignore_case=[])\n\nInput validation\n================\n\nSimilarly to the response documentation, request body examples should be representative of a functioning request body. If you use Django Rest Framework\'s `Serializer` class for input validation, it is simple to make sure that all your documented request bodies would pass input validation for all endpoints.\n\nThis is currently under development and will be added for v1.0.0\n',
    'author': 'Sondre Lillebø Gundersen',
    'author_email': 'sondrelg@live.no',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/sondrelg/django-swagger-tester',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.5,<4.0',
}


setup(**setup_kwargs)
